@@ -4,12 +4,14 @@ Main interface for rekognition service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_rekognition import (
         Client,
         DescribeProjectVersionsPaginator,
         DescribeProjectsPaginator,
         ListCollectionsPaginator,
+        ListDatasetEntriesPaginator,
+        ListDatasetLabelsPaginator,
         ListFacesPaginator,
         ListStreamProcessorsPaginator,
         ProjectVersionRunningWaiter,
@@ -17,10 +19,8 @@ Usage::
         RekognitionClient,
     )
 
-    session = boto3.Session()
-
-    client: RekognitionClient = boto3.client("rekognition")
-    session_client: RekognitionClient = session.client("rekognition")
+    session = Session()
+    client: RekognitionClient = session.client("rekognition")
 
     project_version_running_waiter: ProjectVersionRunningWaiter = client.get_waiter("project_version_running")
     project_version_training_completed_waiter: ProjectVersionTrainingCompletedWaiter = client.get_waiter("project_version_training_completed")
@@ -28,6 +28,8 @@ Usage::
     describe_project_versions_paginator: DescribeProjectVersionsPaginator = client.get_paginator("describe_project_versions")
     describe_projects_paginator: DescribeProjectsPaginator = client.get_paginator("describe_projects")
     list_collections_paginator: ListCollectionsPaginator = client.get_paginator("list_collections")
+    list_dataset_entries_paginator: ListDatasetEntriesPaginator = client.get_paginator("list_dataset_entries")
+    list_dataset_labels_paginator: ListDatasetLabelsPaginator = client.get_paginator("list_dataset_labels")
     list_faces_paginator: ListFacesPaginator = client.get_paginator("list_faces")
     list_stream_processors_paginator: ListStreamProcessorsPaginator = client.get_paginator("list_stream_processors")
     ```
@@ -37,6 +39,8 @@ from .paginator import (
     DescribeProjectsPaginator,
     DescribeProjectVersionsPaginator,
     ListCollectionsPaginator,
+    ListDatasetEntriesPaginator,
+    ListDatasetLabelsPaginator,
     ListFacesPaginator,
     ListStreamProcessorsPaginator,
 )
@@ -50,6 +54,8 @@ __all__ = (
     "DescribeProjectVersionsPaginator",
     "DescribeProjectsPaginator",
     "ListCollectionsPaginator",
+    "ListDatasetEntriesPaginator",
+    "ListDatasetLabelsPaginator",
     "ListFacesPaginator",
     "ListStreamProcessorsPaginator",
     "ProjectVersionRunningWaiter",
