@@ -1,7 +1,7 @@
 """
 Type annotations for rekognition service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rekognition/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rekognition/literals/)
 
 Usage::
 
@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -25,6 +25,9 @@ __all__ = (
     "CelebrityRecognitionSortByType",
     "ContentClassifierType",
     "ContentModerationSortByType",
+    "DatasetStatusMessageCodeType",
+    "DatasetStatusType",
+    "DatasetTypeType",
     "DescribeProjectVersionsPaginatorName",
     "DescribeProjectsPaginatorName",
     "EmotionNameType",
@@ -35,6 +38,8 @@ __all__ = (
     "LabelDetectionSortByType",
     "LandmarkTypeType",
     "ListCollectionsPaginatorName",
+    "ListDatasetEntriesPaginatorName",
+    "ListDatasetLabelsPaginatorName",
     "ListFacesPaginatorName",
     "ListStreamProcessorsPaginatorName",
     "OrientationCorrectionType",
@@ -47,12 +52,18 @@ __all__ = (
     "QualityFilterType",
     "ReasonType",
     "SegmentTypeType",
+    "StreamProcessorParameterToDeleteType",
     "StreamProcessorStatusType",
     "TechnicalCueTypeType",
     "TextTypesType",
     "VideoColorRangeType",
     "VideoJobStatusType",
+    "RekognitionServiceName",
     "ServiceName",
+    "ResourceServiceName",
+    "PaginatorName",
+    "WaiterName",
+    "RegionName",
 )
 
 
@@ -61,6 +72,17 @@ BodyPartType = Literal["FACE", "HEAD", "LEFT_HAND", "RIGHT_HAND"]
 CelebrityRecognitionSortByType = Literal["ID", "TIMESTAMP"]
 ContentClassifierType = Literal["FreeOfAdultContent", "FreeOfPersonallyIdentifiableInformation"]
 ContentModerationSortByType = Literal["NAME", "TIMESTAMP"]
+DatasetStatusMessageCodeType = Literal["CLIENT_ERROR", "SERVICE_ERROR", "SUCCESS"]
+DatasetStatusType = Literal[
+    "CREATE_COMPLETE",
+    "CREATE_FAILED",
+    "CREATE_IN_PROGRESS",
+    "DELETE_IN_PROGRESS",
+    "UPDATE_COMPLETE",
+    "UPDATE_FAILED",
+    "UPDATE_IN_PROGRESS",
+]
+DatasetTypeType = Literal["TEST", "TRAIN"]
 DescribeProjectVersionsPaginatorName = Literal["describe_project_versions"]
 DescribeProjectsPaginatorName = Literal["describe_projects"]
 EmotionNameType = Literal[
@@ -69,7 +91,7 @@ EmotionNameType = Literal[
 FaceAttributesType = Literal["ALL", "DEFAULT"]
 FaceSearchSortByType = Literal["INDEX", "TIMESTAMP"]
 GenderTypeType = Literal["Female", "Male"]
-KnownGenderTypeType = Literal["Female", "Male"]
+KnownGenderTypeType = Literal["Female", "Male", "Nonbinary", "Unlisted"]
 LabelDetectionSortByType = Literal["NAME", "TIMESTAMP"]
 LandmarkTypeType = Literal[
     "chinBottom",
@@ -104,6 +126,8 @@ LandmarkTypeType = Literal[
     "upperJawlineRight",
 ]
 ListCollectionsPaginatorName = Literal["list_collections"]
+ListDatasetEntriesPaginatorName = Literal["list_dataset_entries"]
+ListDatasetLabelsPaginatorName = Literal["list_dataset_labels"]
 ListFacesPaginatorName = Literal["list_faces"]
 ListStreamProcessorsPaginatorName = Literal["list_stream_processors"]
 OrientationCorrectionType = Literal["ROTATE_0", "ROTATE_180", "ROTATE_270", "ROTATE_90"]
@@ -134,25 +158,32 @@ ReasonType = Literal[
     "SMALL_BOUNDING_BOX",
 ]
 SegmentTypeType = Literal["SHOT", "TECHNICAL_CUE"]
-StreamProcessorStatusType = Literal["FAILED", "RUNNING", "STARTING", "STOPPED", "STOPPING"]
+StreamProcessorParameterToDeleteType = Literal["ConnectedHomeMinConfidence", "RegionsOfInterest"]
+StreamProcessorStatusType = Literal[
+    "FAILED", "RUNNING", "STARTING", "STOPPED", "STOPPING", "UPDATING"
+]
 TechnicalCueTypeType = Literal[
     "BlackFrames", "ColorBars", "Content", "EndCredits", "OpeningCredits", "Slate", "StudioLogo"
 ]
 TextTypesType = Literal["LINE", "WORD"]
 VideoColorRangeType = Literal["FULL", "LIMITED"]
 VideoJobStatusType = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED"]
+RekognitionServiceName = Literal["rekognition"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -167,14 +198,19 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
@@ -219,6 +255,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -240,6 +277,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -250,9 +288,11 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
+    "grafana",
     "greengrass",
     "greengrassv2",
     "groundstation",
@@ -265,6 +305,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -278,11 +319,14 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -323,7 +367,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -337,6 +383,7 @@ ServiceName = Literal[
     "opsworkscm",
     "organizations",
     "outposts",
+    "panorama",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -344,6 +391,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -351,11 +399,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -365,6 +415,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -411,14 +462,54 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
+PaginatorName = Literal[
+    "describe_project_versions",
+    "describe_projects",
+    "list_collections",
+    "list_dataset_entries",
+    "list_dataset_labels",
+    "list_faces",
+    "list_stream_processors",
+]
+WaiterName = Literal["project_version_running", "project_version_training_completed"]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-west-1",
+    "eu-west-2",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
