@@ -1,7 +1,7 @@
 """
 Type annotations for rekognition service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rekognition/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rekognition/type_defs/)
 
 Usage::
 
@@ -23,6 +23,9 @@ from .literals import (
     CelebrityRecognitionSortByType,
     ContentClassifierType,
     ContentModerationSortByType,
+    DatasetStatusMessageCodeType,
+    DatasetStatusType,
+    DatasetTypeType,
     EmotionNameType,
     FaceAttributesType,
     FaceSearchSortByType,
@@ -38,6 +41,7 @@ from .literals import (
     QualityFilterType,
     ReasonType,
     SegmentTypeType,
+    StreamProcessorParameterToDeleteType,
     StreamProcessorStatusType,
     TechnicalCueTypeType,
     TextTypesType,
@@ -45,7 +49,7 @@ from .literals import (
     VideoJobStatusType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -66,10 +70,14 @@ __all__ = (
     "CompareFacesResponseTypeDef",
     "ComparedFaceTypeDef",
     "ComparedSourceImageFaceTypeDef",
+    "ConnectedHomeSettingsForUpdateTypeDef",
+    "ConnectedHomeSettingsTypeDef",
     "ContentModerationDetectionTypeDef",
     "CoversBodyPartTypeDef",
     "CreateCollectionRequestRequestTypeDef",
     "CreateCollectionResponseTypeDef",
+    "CreateDatasetRequestRequestTypeDef",
+    "CreateDatasetResponseTypeDef",
     "CreateProjectRequestRequestTypeDef",
     "CreateProjectResponseTypeDef",
     "CreateProjectVersionRequestRequestTypeDef",
@@ -77,8 +85,16 @@ __all__ = (
     "CreateStreamProcessorRequestRequestTypeDef",
     "CreateStreamProcessorResponseTypeDef",
     "CustomLabelTypeDef",
+    "DatasetChangesTypeDef",
+    "DatasetDescriptionTypeDef",
+    "DatasetLabelDescriptionTypeDef",
+    "DatasetLabelStatsTypeDef",
+    "DatasetMetadataTypeDef",
+    "DatasetSourceTypeDef",
+    "DatasetStatsTypeDef",
     "DeleteCollectionRequestRequestTypeDef",
     "DeleteCollectionResponseTypeDef",
+    "DeleteDatasetRequestRequestTypeDef",
     "DeleteFacesRequestRequestTypeDef",
     "DeleteFacesResponseTypeDef",
     "DeleteProjectRequestRequestTypeDef",
@@ -88,8 +104,14 @@ __all__ = (
     "DeleteStreamProcessorRequestRequestTypeDef",
     "DescribeCollectionRequestRequestTypeDef",
     "DescribeCollectionResponseTypeDef",
+    "DescribeDatasetRequestRequestTypeDef",
+    "DescribeDatasetResponseTypeDef",
+    "DescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef",
+    "DescribeProjectVersionsRequestProjectVersionRunningWaitTypeDef",
+    "DescribeProjectVersionsRequestProjectVersionTrainingCompletedWaitTypeDef",
     "DescribeProjectVersionsRequestRequestTypeDef",
     "DescribeProjectVersionsResponseTypeDef",
+    "DescribeProjectsRequestDescribeProjectsPaginateTypeDef",
     "DescribeProjectsRequestRequestTypeDef",
     "DescribeProjectsResponseTypeDef",
     "DescribeStreamProcessorRequestRequestTypeDef",
@@ -108,6 +130,8 @@ __all__ = (
     "DetectTextRequestRequestTypeDef",
     "DetectTextResponseTypeDef",
     "DetectionFilterTypeDef",
+    "DistributeDatasetEntriesRequestRequestTypeDef",
+    "DistributeDatasetTypeDef",
     "EmotionTypeDef",
     "EquipmentDetectionTypeDef",
     "EvaluationResultTypeDef",
@@ -149,15 +173,25 @@ __all__ = (
     "IndexFacesResponseTypeDef",
     "InstanceTypeDef",
     "KinesisDataStreamTypeDef",
+    "KinesisVideoStreamStartSelectorTypeDef",
     "KinesisVideoStreamTypeDef",
     "KnownGenderTypeDef",
     "LabelDetectionTypeDef",
     "LabelTypeDef",
     "LandmarkTypeDef",
+    "ListCollectionsRequestListCollectionsPaginateTypeDef",
     "ListCollectionsRequestRequestTypeDef",
     "ListCollectionsResponseTypeDef",
+    "ListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef",
+    "ListDatasetEntriesRequestRequestTypeDef",
+    "ListDatasetEntriesResponseTypeDef",
+    "ListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef",
+    "ListDatasetLabelsRequestRequestTypeDef",
+    "ListDatasetLabelsResponseTypeDef",
+    "ListFacesRequestListFacesPaginateTypeDef",
     "ListFacesRequestRequestTypeDef",
     "ListFacesResponseTypeDef",
+    "ListStreamProcessorsRequestListStreamProcessorsPaginateTypeDef",
     "ListStreamProcessorsRequestRequestTypeDef",
     "ListStreamProcessorsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -184,6 +218,7 @@ __all__ = (
     "RecognizeCelebritiesResponseTypeDef",
     "RegionOfInterestTypeDef",
     "ResponseMetadataTypeDef",
+    "S3DestinationTypeDef",
     "S3ObjectTypeDef",
     "SearchFacesByImageRequestRequestTypeDef",
     "SearchFacesByImageResponseTypeDef",
@@ -212,6 +247,7 @@ __all__ = (
     "StartSegmentDetectionResponseTypeDef",
     "StartShotDetectionFilterTypeDef",
     "StartStreamProcessorRequestRequestTypeDef",
+    "StartStreamProcessorResponseTypeDef",
     "StartTechnicalCueDetectionFilterTypeDef",
     "StartTextDetectionFiltersTypeDef",
     "StartTextDetectionRequestRequestTypeDef",
@@ -219,8 +255,13 @@ __all__ = (
     "StopProjectVersionRequestRequestTypeDef",
     "StopProjectVersionResponseTypeDef",
     "StopStreamProcessorRequestRequestTypeDef",
+    "StreamProcessingStartSelectorTypeDef",
+    "StreamProcessingStopSelectorTypeDef",
+    "StreamProcessorDataSharingPreferenceTypeDef",
     "StreamProcessorInputTypeDef",
+    "StreamProcessorNotificationChannelTypeDef",
     "StreamProcessorOutputTypeDef",
+    "StreamProcessorSettingsForUpdateTypeDef",
     "StreamProcessorSettingsTypeDef",
     "StreamProcessorTypeDef",
     "SummaryTypeDef",
@@ -235,6 +276,8 @@ __all__ = (
     "TrainingDataTypeDef",
     "UnindexedFaceTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "UpdateDatasetEntriesRequestRequestTypeDef",
+    "UpdateStreamProcessorRequestRequestTypeDef",
     "ValidationDataTypeDef",
     "VideoMetadataTypeDef",
     "VideoTypeDef",
@@ -307,6 +350,7 @@ CelebrityDetailTypeDef = TypedDict(
         "Confidence": float,
         "BoundingBox": "BoundingBoxTypeDef",
         "Face": "FaceDetailTypeDef",
+        "KnownGender": "KnownGenderTypeDef",
     },
     total=False,
 )
@@ -400,6 +444,36 @@ ComparedSourceImageFaceTypeDef = TypedDict(
     total=False,
 )
 
+ConnectedHomeSettingsForUpdateTypeDef = TypedDict(
+    "ConnectedHomeSettingsForUpdateTypeDef",
+    {
+        "Labels": Sequence[str],
+        "MinConfidence": float,
+    },
+    total=False,
+)
+
+_RequiredConnectedHomeSettingsTypeDef = TypedDict(
+    "_RequiredConnectedHomeSettingsTypeDef",
+    {
+        "Labels": Sequence[str],
+    },
+)
+_OptionalConnectedHomeSettingsTypeDef = TypedDict(
+    "_OptionalConnectedHomeSettingsTypeDef",
+    {
+        "MinConfidence": float,
+    },
+    total=False,
+)
+
+
+class ConnectedHomeSettingsTypeDef(
+    _RequiredConnectedHomeSettingsTypeDef, _OptionalConnectedHomeSettingsTypeDef
+):
+    pass
+
+
 ContentModerationDetectionTypeDef = TypedDict(
     "ContentModerationDetectionTypeDef",
     {
@@ -449,6 +523,36 @@ CreateCollectionResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetRequestRequestTypeDef",
+    {
+        "DatasetType": DatasetTypeType,
+        "ProjectArn": str,
+    },
+)
+_OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetRequestRequestTypeDef",
+    {
+        "DatasetSource": "DatasetSourceTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateDatasetRequestRequestTypeDef(
+    _RequiredCreateDatasetRequestRequestTypeDef, _OptionalCreateDatasetRequestRequestTypeDef
+):
+    pass
+
+
+CreateDatasetResponseTypeDef = TypedDict(
+    "CreateDatasetResponseTypeDef",
+    {
+        "DatasetArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 CreateProjectRequestRequestTypeDef = TypedDict(
     "CreateProjectRequestRequestTypeDef",
     {
@@ -470,13 +574,13 @@ _RequiredCreateProjectVersionRequestRequestTypeDef = TypedDict(
         "ProjectArn": str,
         "VersionName": str,
         "OutputConfig": "OutputConfigTypeDef",
-        "TrainingData": "TrainingDataTypeDef",
-        "TestingData": "TestingDataTypeDef",
     },
 )
 _OptionalCreateProjectVersionRequestRequestTypeDef = TypedDict(
     "_OptionalCreateProjectVersionRequestRequestTypeDef",
     {
+        "TrainingData": "TrainingDataTypeDef",
+        "TestingData": "TestingDataTypeDef",
         "Tags": Mapping[str, str],
         "KmsKeyId": str,
     },
@@ -513,6 +617,10 @@ _OptionalCreateStreamProcessorRequestRequestTypeDef = TypedDict(
     "_OptionalCreateStreamProcessorRequestRequestTypeDef",
     {
         "Tags": Mapping[str, str],
+        "NotificationChannel": "StreamProcessorNotificationChannelTypeDef",
+        "KmsKeyId": str,
+        "RegionsOfInterest": Sequence["RegionOfInterestTypeDef"],
+        "DataSharingPreference": "StreamProcessorDataSharingPreferenceTypeDef",
     },
     total=False,
 )
@@ -543,6 +651,77 @@ CustomLabelTypeDef = TypedDict(
     total=False,
 )
 
+DatasetChangesTypeDef = TypedDict(
+    "DatasetChangesTypeDef",
+    {
+        "GroundTruth": Union[str, bytes, IO[Any], StreamingBody],
+    },
+)
+
+DatasetDescriptionTypeDef = TypedDict(
+    "DatasetDescriptionTypeDef",
+    {
+        "CreationTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "Status": DatasetStatusType,
+        "StatusMessage": str,
+        "StatusMessageCode": DatasetStatusMessageCodeType,
+        "DatasetStats": "DatasetStatsTypeDef",
+    },
+    total=False,
+)
+
+DatasetLabelDescriptionTypeDef = TypedDict(
+    "DatasetLabelDescriptionTypeDef",
+    {
+        "LabelName": str,
+        "LabelStats": "DatasetLabelStatsTypeDef",
+    },
+    total=False,
+)
+
+DatasetLabelStatsTypeDef = TypedDict(
+    "DatasetLabelStatsTypeDef",
+    {
+        "EntryCount": int,
+        "BoundingBoxCount": int,
+    },
+    total=False,
+)
+
+DatasetMetadataTypeDef = TypedDict(
+    "DatasetMetadataTypeDef",
+    {
+        "CreationTimestamp": datetime,
+        "DatasetType": DatasetTypeType,
+        "DatasetArn": str,
+        "Status": DatasetStatusType,
+        "StatusMessage": str,
+        "StatusMessageCode": DatasetStatusMessageCodeType,
+    },
+    total=False,
+)
+
+DatasetSourceTypeDef = TypedDict(
+    "DatasetSourceTypeDef",
+    {
+        "GroundTruthManifest": "GroundTruthManifestTypeDef",
+        "DatasetArn": str,
+    },
+    total=False,
+)
+
+DatasetStatsTypeDef = TypedDict(
+    "DatasetStatsTypeDef",
+    {
+        "LabeledEntries": int,
+        "TotalEntries": int,
+        "TotalLabels": int,
+        "ErrorEntries": int,
+    },
+    total=False,
+)
+
 DeleteCollectionRequestRequestTypeDef = TypedDict(
     "DeleteCollectionRequestRequestTypeDef",
     {
@@ -558,6 +737,13 @@ DeleteCollectionResponseTypeDef = TypedDict(
     },
 )
 
+DeleteDatasetRequestRequestTypeDef = TypedDict(
+    "DeleteDatasetRequestRequestTypeDef",
+    {
+        "DatasetArn": str,
+    },
+)
+
 DeleteFacesRequestRequestTypeDef = TypedDict(
     "DeleteFacesRequestRequestTypeDef",
     {
@@ -629,6 +815,94 @@ DescribeCollectionResponseTypeDef = TypedDict(
     },
 )
 
+DescribeDatasetRequestRequestTypeDef = TypedDict(
+    "DescribeDatasetRequestRequestTypeDef",
+    {
+        "DatasetArn": str,
+    },
+)
+
+DescribeDatasetResponseTypeDef = TypedDict(
+    "DescribeDatasetResponseTypeDef",
+    {
+        "DatasetDescription": "DatasetDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef = TypedDict(
+    "_RequiredDescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef",
+    {
+        "ProjectArn": str,
+    },
+)
+_OptionalDescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef = TypedDict(
+    "_OptionalDescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef",
+    {
+        "VersionNames": Sequence[str],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef(
+    _RequiredDescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef,
+    _OptionalDescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredDescribeProjectVersionsRequestProjectVersionRunningWaitTypeDef = TypedDict(
+    "_RequiredDescribeProjectVersionsRequestProjectVersionRunningWaitTypeDef",
+    {
+        "ProjectArn": str,
+    },
+)
+_OptionalDescribeProjectVersionsRequestProjectVersionRunningWaitTypeDef = TypedDict(
+    "_OptionalDescribeProjectVersionsRequestProjectVersionRunningWaitTypeDef",
+    {
+        "VersionNames": Sequence[str],
+        "NextToken": str,
+        "MaxResults": int,
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeProjectVersionsRequestProjectVersionRunningWaitTypeDef(
+    _RequiredDescribeProjectVersionsRequestProjectVersionRunningWaitTypeDef,
+    _OptionalDescribeProjectVersionsRequestProjectVersionRunningWaitTypeDef,
+):
+    pass
+
+
+_RequiredDescribeProjectVersionsRequestProjectVersionTrainingCompletedWaitTypeDef = TypedDict(
+    "_RequiredDescribeProjectVersionsRequestProjectVersionTrainingCompletedWaitTypeDef",
+    {
+        "ProjectArn": str,
+    },
+)
+_OptionalDescribeProjectVersionsRequestProjectVersionTrainingCompletedWaitTypeDef = TypedDict(
+    "_OptionalDescribeProjectVersionsRequestProjectVersionTrainingCompletedWaitTypeDef",
+    {
+        "VersionNames": Sequence[str],
+        "NextToken": str,
+        "MaxResults": int,
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeProjectVersionsRequestProjectVersionTrainingCompletedWaitTypeDef(
+    _RequiredDescribeProjectVersionsRequestProjectVersionTrainingCompletedWaitTypeDef,
+    _OptionalDescribeProjectVersionsRequestProjectVersionTrainingCompletedWaitTypeDef,
+):
+    pass
+
+
 _RequiredDescribeProjectVersionsRequestRequestTypeDef = TypedDict(
     "_RequiredDescribeProjectVersionsRequestRequestTypeDef",
     {
@@ -662,11 +936,21 @@ DescribeProjectVersionsResponseTypeDef = TypedDict(
     },
 )
 
+DescribeProjectsRequestDescribeProjectsPaginateTypeDef = TypedDict(
+    "DescribeProjectsRequestDescribeProjectsPaginateTypeDef",
+    {
+        "ProjectNames": Sequence[str],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 DescribeProjectsRequestRequestTypeDef = TypedDict(
     "DescribeProjectsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
+        "ProjectNames": Sequence[str],
     },
     total=False,
 )
@@ -700,6 +984,10 @@ DescribeStreamProcessorResponseTypeDef = TypedDict(
         "Output": "StreamProcessorOutputTypeDef",
         "RoleArn": str,
         "Settings": "StreamProcessorSettingsTypeDef",
+        "NotificationChannel": "StreamProcessorNotificationChannelTypeDef",
+        "KmsKeyId": str,
+        "RegionsOfInterest": List["RegionOfInterestTypeDef"],
+        "DataSharingPreference": "StreamProcessorDataSharingPreferenceTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -912,6 +1200,20 @@ DetectionFilterTypeDef = TypedDict(
     total=False,
 )
 
+DistributeDatasetEntriesRequestRequestTypeDef = TypedDict(
+    "DistributeDatasetEntriesRequestRequestTypeDef",
+    {
+        "Datasets": Sequence["DistributeDatasetTypeDef"],
+    },
+)
+
+DistributeDatasetTypeDef = TypedDict(
+    "DistributeDatasetTypeDef",
+    {
+        "Arn": str,
+    },
+)
+
 EmotionTypeDef = TypedDict(
     "EmotionTypeDef",
     {
@@ -1025,6 +1327,7 @@ FaceTypeDef = TypedDict(
         "ImageId": str,
         "ExternalImageId": str,
         "Confidence": float,
+        "IndexFacesModelVersion": str,
     },
     total=False,
 )
@@ -1407,7 +1710,7 @@ ImageQualityTypeDef = TypedDict(
 ImageTypeDef = TypedDict(
     "ImageTypeDef",
     {
-        "Bytes": Union[bytes, IO[bytes], StreamingBody],
+        "Bytes": Union[str, bytes, IO[Any], StreamingBody],
         "S3Object": "S3ObjectTypeDef",
     },
     total=False,
@@ -1466,6 +1769,15 @@ KinesisDataStreamTypeDef = TypedDict(
     total=False,
 )
 
+KinesisVideoStreamStartSelectorTypeDef = TypedDict(
+    "KinesisVideoStreamStartSelectorTypeDef",
+    {
+        "ProducerTimestamp": int,
+        "FragmentNumber": str,
+    },
+    total=False,
+)
+
 KinesisVideoStreamTypeDef = TypedDict(
     "KinesisVideoStreamTypeDef",
     {
@@ -1512,6 +1824,14 @@ LandmarkTypeDef = TypedDict(
     total=False,
 )
 
+ListCollectionsRequestListCollectionsPaginateTypeDef = TypedDict(
+    "ListCollectionsRequestListCollectionsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListCollectionsRequestRequestTypeDef = TypedDict(
     "ListCollectionsRequestRequestTypeDef",
     {
@@ -1531,6 +1851,143 @@ ListCollectionsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef = TypedDict(
+    "_RequiredListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef",
+    {
+        "DatasetArn": str,
+    },
+)
+_OptionalListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef = TypedDict(
+    "_OptionalListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef",
+    {
+        "ContainsLabels": Sequence[str],
+        "Labeled": bool,
+        "SourceRefContains": str,
+        "HasErrors": bool,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef(
+    _RequiredListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef,
+    _OptionalListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListDatasetEntriesRequestRequestTypeDef = TypedDict(
+    "_RequiredListDatasetEntriesRequestRequestTypeDef",
+    {
+        "DatasetArn": str,
+    },
+)
+_OptionalListDatasetEntriesRequestRequestTypeDef = TypedDict(
+    "_OptionalListDatasetEntriesRequestRequestTypeDef",
+    {
+        "ContainsLabels": Sequence[str],
+        "Labeled": bool,
+        "SourceRefContains": str,
+        "HasErrors": bool,
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListDatasetEntriesRequestRequestTypeDef(
+    _RequiredListDatasetEntriesRequestRequestTypeDef,
+    _OptionalListDatasetEntriesRequestRequestTypeDef,
+):
+    pass
+
+
+ListDatasetEntriesResponseTypeDef = TypedDict(
+    "ListDatasetEntriesResponseTypeDef",
+    {
+        "DatasetEntries": List[str],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef = TypedDict(
+    "_RequiredListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef",
+    {
+        "DatasetArn": str,
+    },
+)
+_OptionalListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef = TypedDict(
+    "_OptionalListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef(
+    _RequiredListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef,
+    _OptionalListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListDatasetLabelsRequestRequestTypeDef = TypedDict(
+    "_RequiredListDatasetLabelsRequestRequestTypeDef",
+    {
+        "DatasetArn": str,
+    },
+)
+_OptionalListDatasetLabelsRequestRequestTypeDef = TypedDict(
+    "_OptionalListDatasetLabelsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListDatasetLabelsRequestRequestTypeDef(
+    _RequiredListDatasetLabelsRequestRequestTypeDef, _OptionalListDatasetLabelsRequestRequestTypeDef
+):
+    pass
+
+
+ListDatasetLabelsResponseTypeDef = TypedDict(
+    "ListDatasetLabelsResponseTypeDef",
+    {
+        "DatasetLabelDescriptions": List["DatasetLabelDescriptionTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListFacesRequestListFacesPaginateTypeDef = TypedDict(
+    "_RequiredListFacesRequestListFacesPaginateTypeDef",
+    {
+        "CollectionId": str,
+    },
+)
+_OptionalListFacesRequestListFacesPaginateTypeDef = TypedDict(
+    "_OptionalListFacesRequestListFacesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListFacesRequestListFacesPaginateTypeDef(
+    _RequiredListFacesRequestListFacesPaginateTypeDef,
+    _OptionalListFacesRequestListFacesPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListFacesRequestRequestTypeDef = TypedDict(
     "_RequiredListFacesRequestRequestTypeDef",
     {
@@ -1563,6 +2020,14 @@ ListFacesResponseTypeDef = TypedDict(
     },
 )
 
+ListStreamProcessorsRequestListStreamProcessorsPaginateTypeDef = TypedDict(
+    "ListStreamProcessorsRequestListStreamProcessorsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListStreamProcessorsRequestRequestTypeDef = TypedDict(
     "ListStreamProcessorsRequestRequestTypeDef",
     {
@@ -1713,6 +2178,7 @@ ProjectDescriptionTypeDef = TypedDict(
         "ProjectArn": str,
         "CreationTimestamp": datetime,
         "Status": ProjectStatusType,
+        "Datasets": List["DatasetMetadataTypeDef"],
     },
     total=False,
 )
@@ -1797,6 +2263,7 @@ RegionOfInterestTypeDef = TypedDict(
     "RegionOfInterestTypeDef",
     {
         "BoundingBox": "BoundingBoxTypeDef",
+        "Polygon": Sequence["PointTypeDef"],
     },
     total=False,
 )
@@ -1807,11 +2274,20 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
 
+S3DestinationTypeDef = TypedDict(
+    "S3DestinationTypeDef",
+    {
+        "Bucket": str,
+        "KeyPrefix": str,
+    },
+    total=False,
+)
+
 S3ObjectTypeDef = TypedDict(
     "S3ObjectTypeDef",
     {
@@ -2200,12 +2676,36 @@ StartShotDetectionFilterTypeDef = TypedDict(
     total=False,
 )
 
-StartStreamProcessorRequestRequestTypeDef = TypedDict(
-    "StartStreamProcessorRequestRequestTypeDef",
+_RequiredStartStreamProcessorRequestRequestTypeDef = TypedDict(
+    "_RequiredStartStreamProcessorRequestRequestTypeDef",
     {
         "Name": str,
     },
 )
+_OptionalStartStreamProcessorRequestRequestTypeDef = TypedDict(
+    "_OptionalStartStreamProcessorRequestRequestTypeDef",
+    {
+        "StartSelector": "StreamProcessingStartSelectorTypeDef",
+        "StopSelector": "StreamProcessingStopSelectorTypeDef",
+    },
+    total=False,
+)
+
+
+class StartStreamProcessorRequestRequestTypeDef(
+    _RequiredStartStreamProcessorRequestRequestTypeDef,
+    _OptionalStartStreamProcessorRequestRequestTypeDef,
+):
+    pass
+
+
+StartStreamProcessorResponseTypeDef = TypedDict(
+    "StartStreamProcessorResponseTypeDef",
+    {
+        "SessionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
 
 StartTechnicalCueDetectionFilterTypeDef = TypedDict(
     "StartTechnicalCueDetectionFilterTypeDef",
@@ -2280,6 +2780,29 @@ StopStreamProcessorRequestRequestTypeDef = TypedDict(
     },
 )
 
+StreamProcessingStartSelectorTypeDef = TypedDict(
+    "StreamProcessingStartSelectorTypeDef",
+    {
+        "KVSStreamStartSelector": "KinesisVideoStreamStartSelectorTypeDef",
+    },
+    total=False,
+)
+
+StreamProcessingStopSelectorTypeDef = TypedDict(
+    "StreamProcessingStopSelectorTypeDef",
+    {
+        "MaxDurationInSeconds": int,
+    },
+    total=False,
+)
+
+StreamProcessorDataSharingPreferenceTypeDef = TypedDict(
+    "StreamProcessorDataSharingPreferenceTypeDef",
+    {
+        "OptIn": bool,
+    },
+)
+
 StreamProcessorInputTypeDef = TypedDict(
     "StreamProcessorInputTypeDef",
     {
@@ -2288,10 +2811,26 @@ StreamProcessorInputTypeDef = TypedDict(
     total=False,
 )
 
+StreamProcessorNotificationChannelTypeDef = TypedDict(
+    "StreamProcessorNotificationChannelTypeDef",
+    {
+        "SNSTopicArn": str,
+    },
+)
+
 StreamProcessorOutputTypeDef = TypedDict(
     "StreamProcessorOutputTypeDef",
     {
         "KinesisDataStream": "KinesisDataStreamTypeDef",
+        "S3Destination": "S3DestinationTypeDef",
+    },
+    total=False,
+)
+
+StreamProcessorSettingsForUpdateTypeDef = TypedDict(
+    "StreamProcessorSettingsForUpdateTypeDef",
+    {
+        "ConnectedHomeForUpdate": "ConnectedHomeSettingsForUpdateTypeDef",
     },
     total=False,
 )
@@ -2300,6 +2839,7 @@ StreamProcessorSettingsTypeDef = TypedDict(
     "StreamProcessorSettingsTypeDef",
     {
         "FaceSearch": "FaceSearchSettingsTypeDef",
+        "ConnectedHome": "ConnectedHomeSettingsTypeDef",
     },
     total=False,
 )
@@ -2423,6 +2963,39 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+UpdateDatasetEntriesRequestRequestTypeDef = TypedDict(
+    "UpdateDatasetEntriesRequestRequestTypeDef",
+    {
+        "DatasetArn": str,
+        "Changes": "DatasetChangesTypeDef",
+    },
+)
+
+_RequiredUpdateStreamProcessorRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateStreamProcessorRequestRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalUpdateStreamProcessorRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateStreamProcessorRequestRequestTypeDef",
+    {
+        "SettingsForUpdate": "StreamProcessorSettingsForUpdateTypeDef",
+        "RegionsOfInterestForUpdate": Sequence["RegionOfInterestTypeDef"],
+        "DataSharingPreferenceForUpdate": "StreamProcessorDataSharingPreferenceTypeDef",
+        "ParametersToDelete": Sequence[StreamProcessorParameterToDeleteType],
+    },
+    total=False,
+)
+
+
+class UpdateStreamProcessorRequestRequestTypeDef(
+    _RequiredUpdateStreamProcessorRequestRequestTypeDef,
+    _OptionalUpdateStreamProcessorRequestRequestTypeDef,
+):
+    pass
+
+
 ValidationDataTypeDef = TypedDict(
     "ValidationDataTypeDef",
     {
